import checkTokenIsValid from "@backend/components/checkTokenIsValid"
import getPlayerByIdDB from "@backend/components/getPlayerByIdDB"
import getTokenDB from "@backend/components/getTokenDB"
import getTokenFromBody from "@backend/components/getTokenFromBody"
import sendError from "@backend/components/sendError"
import sendResponse from "@backend/components/sendResponse"
import type { Game } from "@prisma/client"
import type { NextApiRequest, NextApiResponse } from "next"

interface Data {
  games: Game[]
}

export default async function data(
  req: NextApiRequest,
  res: NextApiResponse<Data>
) {
  const context = { req, res }

  return getTokenFromBody(context, (accessToken) => {
    checkTokenIsValid(context, accessToken, (token) => {
      getTokenDB(context, token, (tokenDB) => {
        getPlayerByIdDB(context, tokenDB, (player) => {
          const games: any = {}
          sendResponse(context, {
            message: `Requested data of user: ${player.id} with Access-Token: ${tokenDB.id}`,
            body: { games },
            type: ["debug", "infoCyan"],
          })
        })
      })
    })
  }).catch((err) => sendError(context, err))
}
